==> haskell-test-lib-0.4-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-lib
version:              0.4
visibility:           public
id:                   test-lib-0.4-HVJhUK64zKm8UmYVM0PN2A
key:                  test-lib-0.4-HVJhUK64zKm8UmYVM0PN2A
license:              ISC
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A library to make a quick test-runner script.
description:
    This library makes it easy to define an executable,
    which can find and run a bunch of tests for a binary.

category:             Testing
abi:                  0ca9b4bda68eb8e67c973f98df4b2796
exposed:              True
exposed-modules:      TestLib
hidden-modules:       Paths_test_lib
import-dirs:          /usr/lib/ghc-9.0.2/site-local/test-lib-0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/test-lib-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-lib
hs-libraries:         HStest-lib-0.4-HVJhUK64zKm8UmYVM0PN2A
depends:
    HUnit-1.6.2.0-C1iPOmv2pdMIa65hP6dNHl base-4.15.1.0
    containers-0.6.4.1 directory-1.3.6.2 filepath-1.4.2.1
    process-1.6.13.2 simple-get-opt-0.4-8XY5DGfpnmVHGFQNzMUfki
    test-framework-0.8.2.0-4brGE3aCekAANEUcfwRka6
    test-framework-hunit-0.3.0.2-dHl01XwQBj9pjduMrxZoU

haddock-interfaces:   /usr/share/doc/haskell-test-lib/html/test-lib.haddock
haddock-html:         /usr/share/doc/haskell-test-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-lib-0.4-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-lib
version:              0.4
visibility:           public
id:                   test-lib-0.4-1opNcaZ8edzE5WOFgTBDSU
key:                  test-lib-0.4-1opNcaZ8edzE5WOFgTBDSU
license:              ISC
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A library to make a quick test-runner script.
description:
    This library makes it easy to define an executable,
    which can find and run a bunch of tests for a binary.

category:             Testing
abi:                  7501761d84bdc86d7e1121981db69d85
exposed:              True
exposed-modules:      TestLib
hidden-modules:       Paths_test_lib
import-dirs:          /usr/lib/ghc-9.0.2/site-local/test-lib-0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/test-lib-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-lib
hs-libraries:         HStest-lib-0.4-1opNcaZ8edzE5WOFgTBDSU
depends:
    HUnit-1.6.2.0-2YlCiSccBBKHkKAL6vU8b4 base-4.15.1.0
    containers-0.6.4.1 directory-1.3.6.2 filepath-1.4.2.1
    process-1.6.13.2 simple-get-opt-0.4-8XY5DGfpnmVHGFQNzMUfki
    test-framework-0.8.2.0-FQu6SGobrcvKSdbdGEXsK1
    test-framework-hunit-0.3.0.2-3UsuiQn6w4u7nzoU3Y8Aah

haddock-interfaces:   /usr/share/doc/haskell-test-lib/html/test-lib.haddock
haddock-html:         /usr/share/doc/haskell-test-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
